VERSION = "0.3.16"
PYTHONDIR = "/usr/local/lib/python2.5/site-packages"
BIN_DIR = "/usr/local/bin"
LIB_DIR = "/usr/local/lib"
LOCALE_DIR = "/usr/local/share/locale"
SHARED_DATA_DIR = "/usr/local/share/conduit"
SHARED_MODULE_DIR = "/usr/local/lib/conduit/modules"
DESKTOP_FILE_DIR = "/usr/local/share/applications"

#
# Platform specific implementations
#

#{GnomeVfs, GIO, Python}
FILE_IMPL = "GIO"

#{gtkmozembed, webkit, system}
BROWSER_IMPL = "webkit"

#{GConf,Python}
SETTINGS_IMPL = "GConf"

